==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ConfigurationArgs.builder
import com.pulumi.azurenative.web.kotlin.enums.ActiveRevisionsMode
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Non versioned Container App configuration properties that define the mutable settings of a Container app
 * @property activeRevisionsMode ActiveRevisionsMode controls how active revisions are handled for the Container app:
 * <list><item>Multiple: multiple revisions can be active. If no value if provided, this is the default</item><item>Single: Only one revision can be active at a time. Revision weights can not be used in this mode</item></list>
 * @property ingress Ingress configurations.
 * @property registries Collection of private container registry credentials for containers used by the Container app
 * @property secrets Collection of secrets used by a Container app
 */
public data class ConfigurationArgs(
    public val activeRevisionsMode: Output<Either<String, ActiveRevisionsMode>>? = null,
    public val ingress: Output<IngressArgs>? = null,
    public val registries: Output<List<RegistryCredentialsArgs>>? = null,
    public val secrets: Output<List<SecretArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.ConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.ConfigurationArgs =
        com.pulumi.azurenative.web.inputs.ConfigurationArgs.builder()
            .activeRevisionsMode(
                activeRevisionsMode?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .ingress(ingress?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .registries(
                registries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .secrets(
                secrets?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ConfigurationArgs].
 */
@PulumiTagMarker
public class ConfigurationArgsBuilder internal constructor() {
    private var activeRevisionsMode: Output<Either<String, ActiveRevisionsMode>>? = null

    private var ingress: Output<IngressArgs>? = null

    private var registries: Output<List<RegistryCredentialsArgs>>? = null

    private var secrets: Output<List<SecretArgs>>? = null

    /**
     * @param value ActiveRevisionsMode controls how active revisions are handled for the Container app:
     * <list><item>Multiple: multiple revisions can be active. If no value if provided, this is the default</item><item>Single: Only one revision can be active at a time. Revision weights can not be used in this mode</item></list>
     */
    @JvmName("lbmrygldlroqbkka")
    public suspend fun activeRevisionsMode(`value`: Output<Either<String, ActiveRevisionsMode>>) {
        this.activeRevisionsMode = value
    }

    /**
     * @param value Ingress configurations.
     */
    @JvmName("bbmorumvwpswtysk")
    public suspend fun ingress(`value`: Output<IngressArgs>) {
        this.ingress = value
    }

    /**
     * @param value Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("xwxvwprvdjikgtee")
    public suspend fun registries(`value`: Output<List<RegistryCredentialsArgs>>) {
        this.registries = value
    }

    @JvmName("tcsqsdfpuuwbeflm")
    public suspend fun registries(vararg values: Output<RegistryCredentialsArgs>) {
        this.registries = Output.all(values.asList())
    }

    /**
     * @param values Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("hmtprhgbttfiwupu")
    public suspend fun registries(values: List<Output<RegistryCredentialsArgs>>) {
        this.registries = Output.all(values)
    }

    /**
     * @param value Collection of secrets used by a Container app
     */
    @JvmName("drnsjteatelprqpt")
    public suspend fun secrets(`value`: Output<List<SecretArgs>>) {
        this.secrets = value
    }

    @JvmName("lhvlodwrkhclxhmw")
    public suspend fun secrets(vararg values: Output<SecretArgs>) {
        this.secrets = Output.all(values.asList())
    }

    /**
     * @param values Collection of secrets used by a Container app
     */
    @JvmName("bpipnudmdalliobg")
    public suspend fun secrets(values: List<Output<SecretArgs>>) {
        this.secrets = Output.all(values)
    }

    /**
     * @param value ActiveRevisionsMode controls how active revisions are handled for the Container app:
     * <list><item>Multiple: multiple revisions can be active. If no value if provided, this is the default</item><item>Single: Only one revision can be active at a time. Revision weights can not be used in this mode</item></list>
     */
    @JvmName("otnqeucnhhjmxiws")
    public suspend fun activeRevisionsMode(`value`: Either<String, ActiveRevisionsMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.activeRevisionsMode = mapped
    }

    /**
     * @param value ActiveRevisionsMode controls how active revisions are handled for the Container app:
     * <list><item>Multiple: multiple revisions can be active. If no value if provided, this is the default</item><item>Single: Only one revision can be active at a time. Revision weights can not be used in this mode</item></list>
     */
    @JvmName("rgdpgdsukdajigrf")
    public fun activeRevisionsMode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ActiveRevisionsMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.activeRevisionsMode = mapped
    }

    /**
     * @param value ActiveRevisionsMode controls how active revisions are handled for the Container app:
     * <list><item>Multiple: multiple revisions can be active. If no value if provided, this is the default</item><item>Single: Only one revision can be active at a time. Revision weights can not be used in this mode</item></list>
     */
    @JvmName("gqbbrsfirvlhryya")
    public fun activeRevisionsMode(`value`: ActiveRevisionsMode) {
        val toBeMapped = Either.ofRight<String, ActiveRevisionsMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.activeRevisionsMode = mapped
    }

    /**
     * @param value Ingress configurations.
     */
    @JvmName("oubgpwbitlislhyk")
    public suspend fun ingress(`value`: IngressArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ingress = mapped
    }

    /**
     * @param argument Ingress configurations.
     */
    @JvmName("drtindjqfqafcqjl")
    public suspend fun ingress(argument: suspend IngressArgsBuilder.() -> Unit) {
        val toBeMapped = IngressArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.ingress = mapped
    }

    /**
     * @param value Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("ivpiumyynwhmsxme")
    public suspend fun registries(`value`: List<RegistryCredentialsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registries = mapped
    }

    /**
     * @param argument Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("ejombwxnmidhynhc")
    public suspend fun registries(argument: List<suspend RegistryCredentialsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RegistryCredentialsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.registries = mapped
    }

    /**
     * @param argument Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("ofscjwkfbxjwftlw")
    public suspend fun registries(
        vararg
        argument: suspend RegistryCredentialsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RegistryCredentialsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.registries = mapped
    }

    /**
     * @param argument Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("dtngvcsflnqrorya")
    public suspend fun registries(argument: suspend RegistryCredentialsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(RegistryCredentialsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.registries = mapped
    }

    /**
     * @param values Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("uhgeicdajlhhvtrs")
    public suspend fun registries(vararg values: RegistryCredentialsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.registries = mapped
    }

    /**
     * @param value Collection of secrets used by a Container app
     */
    @JvmName("vgsrwlufrvsftgnu")
    public suspend fun secrets(`value`: List<SecretArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secrets = mapped
    }

    /**
     * @param argument Collection of secrets used by a Container app
     */
    @JvmName("soecftxhlrcrnbmt")
    public suspend fun secrets(argument: List<suspend SecretArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { SecretArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.secrets = mapped
    }

    /**
     * @param argument Collection of secrets used by a Container app
     */
    @JvmName("veoqovupkcaepjsi")
    public suspend fun secrets(vararg argument: suspend SecretArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { SecretArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.secrets = mapped
    }

    /**
     * @param argument Collection of secrets used by a Container app
     */
    @JvmName("cfjvrlvtbjrjxbxu")
    public suspend fun secrets(argument: suspend SecretArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SecretArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.secrets = mapped
    }

    /**
     * @param values Collection of secrets used by a Container app
     */
    @JvmName("oceohciektpxgjey")
    public suspend fun secrets(vararg values: SecretArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secrets = mapped
    }

    internal fun build(): ConfigurationArgs = ConfigurationArgs(
        activeRevisionsMode = activeRevisionsMode,
        ingress = ingress,
        registries = registries,
        secrets = secrets,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ConfigurationArgs.builder
import com.pulumi.azurenative.web.kotlin.enums.ActiveRevisionsMode
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Non versioned Container App configuration properties that define the mutable settings of a Container app
 * @property activeRevisionsMode ActiveRevisionsMode controls how active revisions are handled for the Container app:
 * <list><item>Multiple: multiple revisions can be active. If no value if provided, this is the default</item><item>Single: Only one revision can be active at a time. Revision weights can not be used in this mode</item></list>
 * @property ingress Ingress configurations.
 * @property registries Collection of private container registry credentials for containers used by the Container app
 * @property secrets Collection of secrets used by a Container app
 */
public data class ConfigurationArgs(
    public val activeRevisionsMode: Output<Either<String, ActiveRevisionsMode>>? = null,
    public val ingress: Output<IngressArgs>? = null,
    public val registries: Output<List<RegistryCredentialsArgs>>? = null,
    public val secrets: Output<List<SecretArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.ConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.ConfigurationArgs =
        com.pulumi.azurenative.web.inputs.ConfigurationArgs.builder()
            .activeRevisionsMode(
                activeRevisionsMode?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .ingress(ingress?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .registries(
                registries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .secrets(
                secrets?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ConfigurationArgs].
 */
@PulumiTagMarker
public class ConfigurationArgsBuilder internal constructor() {
    private var activeRevisionsMode: Output<Either<String, ActiveRevisionsMode>>? = null

    private var ingress: Output<IngressArgs>? = null

    private var registries: Output<List<RegistryCredentialsArgs>>? = null

    private var secrets: Output<List<SecretArgs>>? = null

    /**
     * @param value ActiveRevisionsMode controls how active revisions are handled for the Container app:
     * <list><item>Multiple: multiple revisions can be active. If no value if provided, this is the default</item><item>Single: Only one revision can be active at a time. Revision weights can not be used in this mode</item></list>
     */
    @JvmName("ssxqtjisewpbgsmy")
    public suspend fun activeRevisionsMode(`value`: Output<Either<String, ActiveRevisionsMode>>) {
        this.activeRevisionsMode = value
    }

    /**
     * @param value Ingress configurations.
     */
    @JvmName("okrgnguevjyrthic")
    public suspend fun ingress(`value`: Output<IngressArgs>) {
        this.ingress = value
    }

    /**
     * @param value Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("ihjobgaaxnjsjjkc")
    public suspend fun registries(`value`: Output<List<RegistryCredentialsArgs>>) {
        this.registries = value
    }

    @JvmName("kbrqflvwllggcgry")
    public suspend fun registries(vararg values: Output<RegistryCredentialsArgs>) {
        this.registries = Output.all(values.asList())
    }

    /**
     * @param values Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("rovqmpgtdewjwcnl")
    public suspend fun registries(values: List<Output<RegistryCredentialsArgs>>) {
        this.registries = Output.all(values)
    }

    /**
     * @param value Collection of secrets used by a Container app
     */
    @JvmName("wmsunetoxuclpled")
    public suspend fun secrets(`value`: Output<List<SecretArgs>>) {
        this.secrets = value
    }

    @JvmName("xefwkjvcakqovwmu")
    public suspend fun secrets(vararg values: Output<SecretArgs>) {
        this.secrets = Output.all(values.asList())
    }

    /**
     * @param values Collection of secrets used by a Container app
     */
    @JvmName("gpnitpeapxpqitlb")
    public suspend fun secrets(values: List<Output<SecretArgs>>) {
        this.secrets = Output.all(values)
    }

    /**
     * @param value ActiveRevisionsMode controls how active revisions are handled for the Container app:
     * <list><item>Multiple: multiple revisions can be active. If no value if provided, this is the default</item><item>Single: Only one revision can be active at a time. Revision weights can not be used in this mode</item></list>
     */
    @JvmName("hoybkouwmeainvjq")
    public suspend fun activeRevisionsMode(`value`: Either<String, ActiveRevisionsMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.activeRevisionsMode = mapped
    }

    /**
     * @param value ActiveRevisionsMode controls how active revisions are handled for the Container app:
     * <list><item>Multiple: multiple revisions can be active. If no value if provided, this is the default</item><item>Single: Only one revision can be active at a time. Revision weights can not be used in this mode</item></list>
     */
    @JvmName("hheycurasnvevuau")
    public fun activeRevisionsMode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ActiveRevisionsMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.activeRevisionsMode = mapped
    }

    /**
     * @param value ActiveRevisionsMode controls how active revisions are handled for the Container app:
     * <list><item>Multiple: multiple revisions can be active. If no value if provided, this is the default</item><item>Single: Only one revision can be active at a time. Revision weights can not be used in this mode</item></list>
     */
    @JvmName("bsafiibuykcofche")
    public fun activeRevisionsMode(`value`: ActiveRevisionsMode) {
        val toBeMapped = Either.ofRight<String, ActiveRevisionsMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.activeRevisionsMode = mapped
    }

    /**
     * @param value Ingress configurations.
     */
    @JvmName("yadcahmihgdnebqq")
    public suspend fun ingress(`value`: IngressArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ingress = mapped
    }

    /**
     * @param argument Ingress configurations.
     */
    @JvmName("pdloeqeovpjurbjw")
    public suspend fun ingress(argument: suspend IngressArgsBuilder.() -> Unit) {
        val toBeMapped = IngressArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.ingress = mapped
    }

    /**
     * @param value Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("mctlgnxovltddsgw")
    public suspend fun registries(`value`: List<RegistryCredentialsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registries = mapped
    }

    /**
     * @param argument Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("builtokcywynonvg")
    public suspend fun registries(argument: List<suspend RegistryCredentialsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RegistryCredentialsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.registries = mapped
    }

    /**
     * @param argument Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("fqmhwyqpifjlsxgb")
    public suspend fun registries(
        vararg
        argument: suspend RegistryCredentialsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RegistryCredentialsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.registries = mapped
    }

    /**
     * @param argument Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("xgwsxamqlnmrqesi")
    public suspend fun registries(argument: suspend RegistryCredentialsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(RegistryCredentialsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.registries = mapped
    }

    /**
     * @param values Collection of private container registry credentials for containers used by the Container app
     */
    @JvmName("tocjxpjgpwervnur")
    public suspend fun registries(vararg values: RegistryCredentialsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.registries = mapped
    }

    /**
     * @param value Collection of secrets used by a Container app
     */
    @JvmName("ftjfhvfbwggjjouf")
    public suspend fun secrets(`value`: List<SecretArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secrets = mapped
    }

    /**
     * @param argument Collection of secrets used by a Container app
     */
    @JvmName("ecsahbbxfmkviepr")
    public suspend fun secrets(argument: List<suspend SecretArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { SecretArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.secrets = mapped
    }

    /**
     * @param argument Collection of secrets used by a Container app
     */
    @JvmName("etnrwjuockxcbgtq")
    public suspend fun secrets(vararg argument: suspend SecretArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { SecretArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.secrets = mapped
    }

    /**
     * @param argument Collection of secrets used by a Container app
     */
    @JvmName("fhjxbloxaqgyexys")
    public suspend fun secrets(argument: suspend SecretArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SecretArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.secrets = mapped
    }

    /**
     * @param values Collection of secrets used by a Container app
     */
    @JvmName("wkfwlxtcgxxxvfyh")
    public suspend fun secrets(vararg values: SecretArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secrets = mapped
    }

    internal fun build(): ConfigurationArgs = ConfigurationArgs(
        activeRevisionsMode = activeRevisionsMode,
        ingress = ingress,
        registries = registries,
        secrets = secrets,
    )
}
